==> rosegarden-1.6.1.tar.bz2: rosegarden-1.6.1/src/commands/notation/CollapseRestsCommand.h <==

/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.

    This program is Copyright 2000-2007
        Guillaume Laurent   <glaurent@telegraph-road.org>,
        Chris Cannam        <cannam@all-day-breakfast.com>,
        Richard Bown        <richard.bown@ferventsoftware.com>

    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
    Bown to claim authorship of this work have been asserted.

    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef _RG_ADJUSTMENUCOLLAPSERESTSCOMMAND_H_
#define _RG_ADJUSTMENUCOLLAPSERESTSCOMMAND_H_

#include "document/BasicCommand.h"
#include <qstring.h>
#include "base/Event.h"
#include <klocale.h>




namespace Rosegarden
{

class Segment;
class EventSelection;


class CollapseRestsCommand : public BasicCommand
{
public:
    CollapseRestsCommand(Segment &s,
                                       timeT startTime,
                                       timeT endTime) :
        BasicCommand(getGlobalName(), s, startTime, endTime) { }

    CollapseRestsCommand(EventSelection &selection);

    static QString getGlobalName() { return i18n("&Collapse Rests"); }

protected:
    virtual void modifySegment();
};


}

#endif

==> rosegarden_11.11.11.orig.tar.bz2: rosegarden-11.11.11/src/commands/notation/CollapseRestsCommand.h <==

/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.
    Copyright 2000-2011 the Rosegarden development team.

    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef _RG_COLLAPSERESTSCOMMAND_H_
#define _RG_COLLAPSERESTSCOMMAND_H_

#include "document/BasicCommand.h"
#include <QString>
#include "base/Event.h"
#include <QCoreApplication>




namespace Rosegarden
{

class Segment;
class EventSelection;
class CommandRegistry;


class CollapseRestsCommand : public BasicCommand
{
    Q_DECLARE_TR_FUNCTIONS(Rosegarden::CollapseRestsCommand)

public:
    CollapseRestsCommand(Segment &s,
                         timeT startTime,
                         timeT endTime) :
        BasicCommand(getGlobalName(), s, startTime, endTime) { }

    CollapseRestsCommand(EventSelection &selection);

    static QString getGlobalName() { return tr("&Collapse Rests"); }

    static void registerCommand(CommandRegistry *r);

protected:
    virtual void modifySegment();
};


}

#endif
